Please see [https://docs.mlcommons.org/cm4mlops/scripts/MLPerf-benchmark-support/import-mlperf-inference-to-experiment](https://docs.mlcommons.org/cm4mlops/scripts/MLPerf-benchmark-support/import-mlperf-inference-to-experiment) for the documentation of this CM script.
